==> A.powerpc-apple-darwin8.2.0.tar.gz: A.powerpc-apple-darwin8.2.0/dbgcf.h <==

#define PACKAGE_NAME "am-utils"
#define PACKAGE_TARNAME "am-utils"
#define PACKAGE_VERSION "6.2a1"
#define PACKAGE_STRING "am-utils 6.2a1"
#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
#define HOST_CPU "powerpc"
#define HOST_VENDOR "apple"
#define HOST_OS "macosx-10.4.2"
#define HOST_OS_NAME "macosx-10"
#define HOST_OS_VERSION "10.4.2"
#define HOST_ARCH "powerpc"
#define DISTRO_NAME "none"
#define HOST_NAME "a-osx.fsl.cs.sunysb.edu"
#define USER_NAME "ezk"
#define CONFIG_DATE "Fri Oct  7 18:29:46 EDT 2005"
#define PACKAGE_NAME "am-utils"
#define PACKAGE_VERSION "6.2a1"
#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
#define PACKAGE "am-utils"
#define VERSION "6.2a1"
#define DEBUG 1
#define STDC_HEADERS 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRING_H 1
#define HAVE_MEMORY_H 1
#define HAVE_STRINGS_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_STDINT_H 1
#define HAVE_UNISTD_H 1
#define HAVE_DLFCN_H 1
#ifdef __cplusplus
#include <stdlib.h>
#endif
#define HOST_HEADER_VERSION "10.4.2"
#define YYTEXT_POINTER 1
#define HAVE_LIBLDAP 1
#define HAVE_UNISTD_H 1
#define HAVE_FORK 1
#define HAVE_VFORK 1
#define HAVE_WORKING_VFORK 1
#define HAVE_WORKING_FORK 1
#define HAVE_WAIT3 1
#define GETPGRP_VOID 1
#define HAVE__SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_FLOCK 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETIFADDRS 1
#define HAVE_GETMNTINFO 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_HSTRERROR 1
#define HAVE_MADVISE 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MLOCKALL 1
#define HAVE_MOUNT 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETEUID 1
#define HAVE_SETITIMER 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SIGSUSPEND 1
#define HAVE_SOCKET 1
#define HAVE_STATFS 1
#define HAVE_STATVFS 1
#define HAVE_STRCASECMP 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRLCAT 1
#define HAVE_STRLCPY 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UNMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRLCAT 1
#define HAVE_STRLCPY 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_POINTER 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
#define HAVE_MACHINE_ENDIAN_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_IF_VAR_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_NFS_NFSMOUNT_H 1
#define HAVE_NFS_NFSPROTO_H 1
#define HAVE_NFS_RPCV2_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NFS_PROT_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_DIR_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_LOCK_H 1
#define HAVE_SYS_MBUF_H 1
#define HAVE_SYS_MMAN_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PROC_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_SOCKIO_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_STATVFS_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYS_SYSLIMITS_H 1
#define HAVE_SYS_SYSLOG_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UCRED_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VNODE_H 1
#define HAVE_UFS_UFS_UFSMOUNT_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_IFADDRS_H 1
#define HAVE_GRP_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_LIMITS_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETDB_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TCPD_H 1
#define HAVE_TIME_H 1
#define HAVE_UNISTD_H 1
#define HAVE_LBER_H 1
#define HAVE_LDAP_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_darwin.h"
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD fh
#define am_nfs_fh nfs_fh
#define HAVE_FS_NFS3 1
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define rpcvers_t unsigned long
#define HAVE_FHANDLE 1
#define MTYPE_TYPE char *
#define MTYPE_PRINTF_TYPE "%s"
#define YP_ORDER_OUTORDER_TYPE int
#define RECVFROM_FROMLEN_TYPE socklen_t
#define AUTH_CREATE_GIDLIST_TYPE int
#define SVC_IN_ARG_TYPE caddr_t
#define cdfs_args_t struct iso_args
#define mfs_args_t struct mfs_args
#define ufs_args_t struct ufs_args
#define XDRPROC_T_TYPE xdrproc_t
#define WORDS_BIGENDIAN 1
#define voidp void *
#define HAVE_C99_VARARGS_MACROS 1
#define HAVE_EXTERN_SYS_ERRLIST 1
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GETDOMAINNAME 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_INNETGR 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_SETEUID 1
#define HAVE_EXTERN_SETITIMER 1
#define HAVE_EXTERN_SLEEP 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRLCAT 1
#define HAVE_EXTERN_STRLCPY 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_EXTERN_VSNPRINTF 1
#define HAVE_EXTERN_XDR_CALLMSG 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_UNISTD_H 1
#define HAVE_RESTARTABLE_SYSCALLS 1
#define HAVE_FD_SET_FDS_BITS 1
#define HAVE_CDFS_ARGS_T_FLAGS 1
#define HAVE_CDFS_ARGS_T_FSPEC 1
#define HAVE_CDFS_ARGS_T_SSECTOR 1
#define HAVE_UFS_ARGS_T_FSPEC 1
#define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
#define HAVE_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_NFS_ARGS_T_ACDIRMAX 1
#define HAVE_NFS_ARGS_T_ACREGMIN 1
#define HAVE_NFS_ARGS_T_ACREGMAX 1
#define HAVE_NFS_ARGS_T_FHSIZE 1
#define HAVE_NFS_ARGS_T_PROTO 1
#define HAVE_NFS_ARGS_T_SOTYPE 1
#define HAVE_NFS_ARGS_T_VERSION 1
#define HAVE_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
#define HAVE_STRUCT_SOCKADDR_SA_LEN 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_SUN 1
#define HAVE_MAP_EXEC 1
#define HAVE_MAP_LDAP 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_UFS 1
#define HAVE_FS_UNIONFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS "nfs"
#define MOUNT_TYPE_NFS3 MOUNT_NFS3
#define MOUNT_TYPE_UFS "ufs"
#define MOUNT_TYPE_CDFS "cd9660"
#define MOUNT_TYPE_UNIONFS MNT_UNION
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_NFS3 "nfs3"
#define MNTTAB_TYPE_UFS "ufs"
#define MNTTAB_TYPE_CDFS "cd9660"
#define MNTTAB_TYPE_UNIONFS "union"
#define MNT2_GEN_OPT_ASYNC 0x40
#define MNT2_GEN_OPT_FORCE 0x80000
#define MNT2_GEN_OPT_NODEV 0x10
#define MNT2_GEN_OPT_NOEXEC 0x4
#define MNT2_GEN_OPT_NOSUID 0x8
#define MNT2_GEN_OPT_QUOTA 0x2000
#define MNT2_GEN_OPT_RDONLY 0x1
#define MNT2_GEN_OPT_SYNCHRONOUS 0x2
#define MNT2_NFS_OPT_ACDIRMAX 0x800000
#define MNT2_NFS_OPT_ACDIRMIN 0x400000
#define MNT2_NFS_OPT_ACREGMAX 0x200000
#define MNT2_NFS_OPT_ACREGMIN 0x100000
#define MNT2_NFS_OPT_DUMBTIMR 0x800
#define MNT2_NFS_OPT_INT 0x40
#define MNT2_NFS_OPT_KERB 0x400
#define MNT2_NFS_OPT_MAXGRPS 0x20
#define MNT2_NFS_OPT_NFSV3 0x200
#define MNT2_NFS_OPT_NOCONN 0x80
#define MNT2_NFS_OPT_RDIRPLUS 0x10000
#define MNT2_NFS_OPT_READAHEAD 0x2000
#define MNT2_NFS_OPT_READDIRSIZE 0x20000
#define MNT2_NFS_OPT_RESVPORT 0x8000
#define MNT2_NFS_OPT_RETRANS 0x10
#define MNT2_NFS_OPT_RSIZE 0x4
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TIMEO 0x8
#define MNT2_NFS_OPT_WSIZE 0x2
#define MNT2_CDFS_OPT_EXTATT 0x4
#define MNT2_CDFS_OPT_GENS 0x2
#define MNT2_CDFS_OPT_NORRIP 0x1
#define HIDE_MOUNT_TYPE "nfs"
#define HAVE_LIBWRAP 1

==> A.powerpc-apple-darwin8.5.0.tar.gz: A.powerpc-apple-darwin8.5.0/dbgcf.h <==

#define PACKAGE_NAME "am-utils"
#define PACKAGE_TARNAME "am-utils"
#define PACKAGE_VERSION "6.2a2"
#define PACKAGE_STRING "am-utils 6.2a2"
#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
#define HOST_CPU "powerpc"
#define HOST_VENDOR "apple"
#define HOST_OS "macosx-10.4.5"
#define HOST_OS_NAME "macosx-10"
#define HOST_OS_VERSION "10.4.5"
#define HOST_ARCH "powerpc"
#define DISTRO_NAME "none"
#define HOST_NAME "a-osx.fsl.cs.sunysb.edu"
#define USER_NAME "ezk"
#define CONFIG_DATE "Sun Apr 16 18:31:44 EDT 2006"
#define PACKAGE_NAME "am-utils"
#define PACKAGE_VERSION "6.2a2"
#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
#define PACKAGE "am-utils"
#define VERSION "6.2a2"
#define DEBUG 1
#define STDC_HEADERS 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRING_H 1
#define HAVE_MEMORY_H 1
#define HAVE_STRINGS_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_STDINT_H 1
#define HAVE_UNISTD_H 1
#define HAVE_DLFCN_H 1
#ifdef __cplusplus
#include <stdlib.h>
#endif
#define HOST_HEADER_VERSION "10.4.5"
#define YYTEXT_POINTER 1
#define HAVE_LIBLDAP 1
#define HAVE_UNISTD_H 1
#define HAVE_FORK 1
#define HAVE_VFORK 1
#define HAVE_WORKING_VFORK 1
#define HAVE_WORKING_FORK 1
#define HAVE_WAIT3 1
#define GETPGRP_VOID 1
#define HAVE__SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_FLOCK 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETIFADDRS 1
#define HAVE_GETMNTINFO 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_HSTRERROR 1
#define HAVE_MADVISE 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MLOCKALL 1
#define HAVE_MOUNT 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETEUID 1
#define HAVE_SETITIMER 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SIGSUSPEND 1
#define HAVE_SOCKET 1
#define HAVE_STATFS 1
#define HAVE_STATVFS 1
#define HAVE_STRCASECMP 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRLCAT 1
#define HAVE_STRLCPY 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UNMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRLCAT 1
#define HAVE_STRLCPY 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_POINTER 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
#define HAVE_MACHINE_ENDIAN_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_IF_VAR_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_NFS_NFSMOUNT_H 1
#define HAVE_NFS_NFSPROTO_H 1
#define HAVE_NFS_RPCV2_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NFS_PROT_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_DIR_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_LOCK_H 1
#define HAVE_SYS_MBUF_H 1
#define HAVE_SYS_MMAN_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PROC_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_SOCKIO_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_STATVFS_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYS_SYSLIMITS_H 1
#define HAVE_SYS_SYSLOG_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UCRED_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VNODE_H 1
#define HAVE_UFS_UFS_UFSMOUNT_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_IFADDRS_H 1
#define HAVE_GRP_H 1
#define HAVE_LIBGEN_H 1
#define HAVE_LIMITS_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETDB_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TCPD_H 1
#define HAVE_TIME_H 1
#define HAVE_UNISTD_H 1
#define HAVE_LBER_H 1
#define HAVE_LDAP_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_darwin.h"
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD fh
#define am_nfs_fh nfs_fh
#define HAVE_FS_NFS3 1
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define rpcvers_t unsigned long
#define HAVE_FHANDLE 1
#define MTYPE_TYPE char *
#define MTYPE_PRINTF_TYPE "%s"
#define YP_ORDER_OUTORDER_TYPE int
#define RECVFROM_FROMLEN_TYPE socklen_t
#define AUTH_CREATE_GIDLIST_TYPE int
#define SVC_IN_ARG_TYPE caddr_t
#define cdfs_args_t struct iso_args
#define mfs_args_t struct mfs_args
#define ufs_args_t struct ufs_args
#define XDRPROC_T_TYPE xdrproc_t
#define WORDS_BIGENDIAN 1
#define voidp void *
#define HAVE_C99_VARARGS_MACROS 1
#define HAVE_EXTERN_SYS_ERRLIST 1
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GETDOMAINNAME 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_INNETGR 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_SETEUID 1
#define HAVE_EXTERN_SETITIMER 1
#define HAVE_EXTERN_SLEEP 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRLCAT 1
#define HAVE_EXTERN_STRLCPY 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_EXTERN_VSNPRINTF 1
#define HAVE_EXTERN_XDR_CALLMSG 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_UNISTD_H 1
#define HAVE_RESTARTABLE_SYSCALLS 1
#define HAVE_FD_SET_FDS_BITS 1
#define HAVE_CDFS_ARGS_T_FLAGS 1
#define HAVE_CDFS_ARGS_T_FSPEC 1
#define HAVE_CDFS_ARGS_T_SSECTOR 1
#define HAVE_UFS_ARGS_T_FSPEC 1
#define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
#define HAVE_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_NFS_ARGS_T_ACDIRMAX 1
#define HAVE_NFS_ARGS_T_ACREGMIN 1
#define HAVE_NFS_ARGS_T_ACREGMAX 1
#define HAVE_NFS_ARGS_T_ADDRLEN 1
#define HAVE_NFS_ARGS_T_FHSIZE 1
#define HAVE_NFS_ARGS_T_PROTO 1
#define HAVE_NFS_ARGS_T_SOTYPE 1
#define HAVE_NFS_ARGS_T_VERSION 1
#define HAVE_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
#define HAVE_STRUCT_SOCKADDR_SA_LEN 1
#define HAVE_FGETS 1
#define HAVE_MAP_FILE 1
#define HAVE_FGETS 1
#define HAVE_MAP_SUN 1
#define HAVE_WAITPID 1
#define HAVE_MAP_EXEC 1
#define HAVE_LDAP_OPEN 1
#define HAVE_MAP_LDAP 1
#define HAVE_YP_GET_DEFAULT_DOMAIN 1
#define HAVE_MAP_NIS 1
#define HAVE_GETPWNAM 1
#define HAVE_MAP_PASSWD 1
#define HAVE_OPENDIR 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_UFS 1
#define HAVE_FS_UNIONFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS "nfs"
#define MOUNT_TYPE_NFS3 MOUNT_NFS3
#define MOUNT_TYPE_UFS "ufs"
#define MOUNT_TYPE_CDFS "cd9660"
#define MOUNT_TYPE_UNIONFS MNT_UNION
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_NFS3 "nfs"
#define MNTTAB_TYPE_UFS "ufs"
#define MNTTAB_TYPE_CDFS "cd9660"
#define MNTTAB_TYPE_UNIONFS "union"
#define MNT2_GEN_OPT_ASYNC 0x40
#define MNT2_GEN_OPT_FORCE 0x80000
#define MNT2_GEN_OPT_NODEV 0x10
#define MNT2_GEN_OPT_NOEXEC 0x4
#define MNT2_GEN_OPT_NOSUID 0x8
#define MNT2_GEN_OPT_QUOTA 0x2000
#define MNT2_GEN_OPT_RDONLY 0x1
#define MNT2_GEN_OPT_SYNCHRONOUS 0x2
#define MNT2_NFS_OPT_ACDIRMAX 0x800000
#define MNT2_NFS_OPT_ACDIRMIN 0x400000
#define MNT2_NFS_OPT_ACREGMAX 0x200000
#define MNT2_NFS_OPT_ACREGMIN 0x100000
#define MNT2_NFS_OPT_DUMBTIMR 0x800
#define MNT2_NFS_OPT_INT 0x40
#define MNT2_NFS_OPT_KERB 0x400
#define MNT2_NFS_OPT_MAXGRPS 0x20
#define MNT2_NFS_OPT_NFSV3 0x200
#define MNT2_NFS_OPT_NOCONN 0x80
#define MNT2_NFS_OPT_RDIRPLUS 0x10000
#define MNT2_NFS_OPT_READAHEAD 0x2000
#define MNT2_NFS_OPT_READDIRSIZE 0x20000
#define MNT2_NFS_OPT_RESVPORT 0x8000
#define MNT2_NFS_OPT_RETRANS 0x10
#define MNT2_NFS_OPT_RSIZE 0x4
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TIMEO 0x8
#define MNT2_NFS_OPT_WSIZE 0x2
#define MNT2_CDFS_OPT_EXTATT 0x4
#define MNT2_CDFS_OPT_GENS 0x2
#define MNT2_CDFS_OPT_NORRIP 0x1
#define HIDE_MOUNT_TYPE "nfs"
#define HAVE_GETMNTINFO 1
#define HAVE_LIBWRAP 1
